@@ -43,6 +43,7 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import google.protobuf
 
 from google.cloud.compute_v1 import gapic_version as package_version
 
@@ -863,8 +864,8 @@ class GlobalOrganizationOperationsClient(
                 the method description for details.
             operation (str):
                 Name of the Operations resource to
-                return, or its unique numeric
-                identifier.
+                return. Parent is derived from this
+                field.
 
                 This corresponds to the ``operation`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1060,5 +1061,7 @@ DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=package_version.__version__
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__
 
 __all__ = ("GlobalOrganizationOperationsClient",)
