@@ -24,6 +24,7 @@ from google.api_core import gapic_v1, rest_helpers, rest_streaming
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.requests import AuthorizedSession  # type: ignore
+import google.protobuf
 from google.protobuf import json_format
 from requests import __version__ as requests_version
 
@@ -52,6 +53,9 @@ DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     rest_version=f"requests@{requests_version}",
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__
+
 
 class LicensesRestInterceptor:
     """Interceptor for Licenses.
@@ -124,6 +128,14 @@ class LicensesRestInterceptor:
                 logging.log(f"Received response: {response}")
                 return response
 
+            def pre_update(self, request, metadata):
+                logging.log(f"Received request: {request}")
+                return request, metadata
+
+            def post_update(self, response):
+                logging.log(f"Received response: {response}")
+                return response
+
         transport = LicensesRestTransport(interceptor=MyCustomLicensesInterceptor())
         client = LicensesClient(transport=transport)
 
@@ -451,6 +463,50 @@ class LicensesRestInterceptor:
         """
         return response, metadata
 
+    def pre_update(
+        self,
+        request: compute.UpdateLicenseRequest,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[compute.UpdateLicenseRequest, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Pre-rpc interceptor for update
+
+        Override in a subclass to manipulate the request or metadata
+        before they are sent to the Licenses server.
+        """
+        return request, metadata
+
+    def post_update(self, response: compute.Operation) -> compute.Operation:
+        """Post-rpc interceptor for update
+
+        DEPRECATED. Please use the `post_update_with_metadata`
+        interceptor instead.
+
+        Override in a subclass to read or manipulate the response
+        after it is returned by the Licenses server but before
+        it is returned to user code. This `post_update` interceptor runs
+        before the `post_update_with_metadata` interceptor.
+        """
+        return response
+
+    def post_update_with_metadata(
+        self,
+        response: compute.Operation,
+        metadata: Sequence[Tuple[str, Union[str, bytes]]],
+    ) -> Tuple[compute.Operation, Sequence[Tuple[str, Union[str, bytes]]]]:
+        """Post-rpc interceptor for update
+
+        Override in a subclass to read or manipulate the response or metadata after it
+        is returned by the Licenses server but before it is returned to user code.
+
+        We recommend only using this `post_update_with_metadata`
+        interceptor in new development instead of the `post_update` interceptor.
+        When both interceptors are used, this `post_update_with_metadata` interceptor runs after the
+        `post_update` interceptor. The (possibly modified) response returned by
+        `post_update` will be passed to
+        `post_update_with_metadata`.
+        """
+        return response, metadata
+
 
 @dataclasses.dataclass
 class LicensesRestStub:
@@ -1663,6 +1719,175 @@ class LicensesRestTransport(_BaseLicensesRestTransport):
                 )
             return resp
 
+    class _Update(_BaseLicensesRestTransport._BaseUpdate, LicensesRestStub):
+        def __hash__(self):
+            return hash("LicensesRestTransport.Update")
+
+        @staticmethod
+        def _get_response(
+            host,
+            metadata,
+            query_params,
+            session,
+            timeout,
+            transcoded_request,
+            body=None,
+        ):
+            uri = transcoded_request["uri"]
+            method = transcoded_request["method"]
+            headers = dict(metadata)
+            headers["Content-Type"] = "application/json"
+            response = getattr(session, method)(
+                "{host}{uri}".format(host=host, uri=uri),
+                timeout=timeout,
+                headers=headers,
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
+                data=body,
+            )
+            return response
+
+        def __call__(
+            self,
+            request: compute.UpdateLicenseRequest,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: Optional[float] = None,
+            metadata: Sequence[Tuple[str, Union[str, bytes]]] = (),
+        ) -> compute.Operation:
+            r"""Call the update method over HTTP.
+
+            Args:
+                request (~.compute.UpdateLicenseRequest):
+                    The request object. A request message for
+                Licenses.Update. See the method
+                description for details.
+                retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                    should be retried.
+                timeout (float): The timeout for this request.
+                metadata (Sequence[Tuple[str, Union[str, bytes]]]): Key/value pairs which should be
+                    sent along with the request as metadata. Normally, each value must be of type `str`,
+                    but for metadata keys ending with the suffix `-bin`, the corresponding values must
+                    be of type `bytes`.
+
+            Returns:
+                ~.compute.Operation:
+                    Represents an Operation resource. Google Compute Engine
+                has three Operation resources: \*
+                `Global </compute/docs/reference/rest/v1/globalOperations>`__
+                \*
+                `Regional </compute/docs/reference/rest/v1/regionOperations>`__
+                \*
+                `Zonal </compute/docs/reference/rest/v1/zoneOperations>`__
+                You can use an operation resource to manage asynchronous
+                API requests. For more information, read Handling API
+                responses. Operations can be global, regional or zonal.
+                - For global operations, use the ``globalOperations``
+                resource. - For regional operations, use the
+                ``regionOperations`` resource. - For zonal operations,
+                use the ``zoneOperations`` resource. For more
+                information, read Global, Regional, and Zonal Resources.
+                Note that completed Operation resources have a limited
+                retention period.
+
+            """
+
+            http_options = _BaseLicensesRestTransport._BaseUpdate._get_http_options()
+
+            request, metadata = self._interceptor.pre_update(request, metadata)
+            transcoded_request = (
+                _BaseLicensesRestTransport._BaseUpdate._get_transcoded_request(
+                    http_options, request
+                )
+            )
+
+            body = _BaseLicensesRestTransport._BaseUpdate._get_request_body_json(
+                transcoded_request
+            )
+
+            # Jsonify the query params
+            query_params = (
+                _BaseLicensesRestTransport._BaseUpdate._get_query_params_json(
+                    transcoded_request
+                )
+            )
+
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                request_url = "{host}{uri}".format(
+                    host=self._host, uri=transcoded_request["uri"]
+                )
+                method = transcoded_request["method"]
+                try:
+                    request_payload = type(request).to_json(request)
+                except:
+                    request_payload = None
+                http_request = {
+                    "payload": request_payload,
+                    "requestMethod": method,
+                    "requestUrl": request_url,
+                    "headers": dict(metadata),
+                }
+                _LOGGER.debug(
+                    f"Sending request for google.cloud.compute_v1.LicensesClient.Update",
+                    extra={
+                        "serviceName": "google.cloud.compute.v1.Licenses",
+                        "rpcName": "Update",
+                        "httpRequest": http_request,
+                        "metadata": http_request["headers"],
+                    },
+                )
+
+            # Send the request
+            response = LicensesRestTransport._Update._get_response(
+                self._host,
+                metadata,
+                query_params,
+                self._session,
+                timeout,
+                transcoded_request,
+                body,
+            )
+
+            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+            # subclass.
+            if response.status_code >= 400:
+                raise core_exceptions.from_http_response(response)
+
+            # Return the response
+            resp = compute.Operation()
+            pb_resp = compute.Operation.pb(resp)
+
+            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+
+            resp = self._interceptor.post_update(resp)
+            response_metadata = [(k, str(v)) for k, v in response.headers.items()]
+            resp, _ = self._interceptor.post_update_with_metadata(
+                resp, response_metadata
+            )
+            if CLIENT_LOGGING_SUPPORTED and _LOGGER.isEnabledFor(
+                logging.DEBUG
+            ):  # pragma: NO COVER
+                try:
+                    response_payload = compute.Operation.to_json(response)
+                except:
+                    response_payload = None
+                http_response = {
+                    "payload": response_payload,
+                    "headers": dict(response.headers),
+                    "status": response.status_code,
+                }
+                _LOGGER.debug(
+                    "Received response for google.cloud.compute_v1.LicensesClient.update",
+                    extra={
+                        "serviceName": "google.cloud.compute.v1.Licenses",
+                        "rpcName": "Update",
+                        "metadata": http_response["headers"],
+                        "httpResponse": http_response,
+                    },
+                )
+            return resp
+
     @property
     def delete(self) -> Callable[[compute.DeleteLicenseRequest], compute.Operation]:
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
@@ -1715,6 +1940,12 @@ class LicensesRestTransport(_BaseLicensesRestTransport):
         # In C++ this would require a dynamic_cast
         return self._TestIamPermissions(self._session, self._host, self._interceptor)  # type: ignore
 
+    @property
+    def update(self) -> Callable[[compute.UpdateLicenseRequest], compute.Operation]:
+        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
+        # In C++ this would require a dynamic_cast
+        return self._Update(self._session, self._host, self._interceptor)  # type: ignore
+
     @property
     def kind(self) -> str:
         return "rest"
