@@ -24,6 +24,7 @@ from google.api_core import gapic_v1, rest_helpers, rest_streaming
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.requests import AuthorizedSession  # type: ignore
+import google.protobuf
 from google.protobuf import json_format
 from requests import __version__ as requests_version
 
@@ -52,6 +53,9 @@ DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     rest_version=f"requests@{requests_version}",
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__
+
 
 class RegionTargetHttpsProxiesRestInterceptor:
     """Interceptor for RegionTargetHttpsProxies.
@@ -778,11 +782,11 @@ class RegionTargetHttpsProxiesRestTransport(_BaseRegionTargetHttpsProxiesRestTra
                 \*
                 `Regional </compute/docs/reference/rest/v1/regionTargetHttpsProxies>`__
                 A target HTTPS proxy is a component of Google Cloud
-                HTTPS load balancers. \* targetHttpProxies are used by
+                HTTPS load balancers. \* targetHttpsProxies are used by
                 global external Application Load Balancers, classic
                 Application Load Balancers, cross-region internal
                 Application Load Balancers, and Traffic Director. \*
-                regionTargetHttpProxies are used by regional internal
+                regionTargetHttpsProxies are used by regional internal
                 Application Load Balancers and regional external
                 Application Load Balancers. Forwarding rules reference a
                 target HTTPS proxy, and the target proxy then references
