@@ -44,6 +44,7 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import google.protobuf
 
 from google.cloud.compute_v1 import gapic_version as package_version
 
@@ -1035,7 +1036,7 @@ class SnapshotsClient(metaclass=SnapshotsClientMeta):
                 resource. You can use snapshots to back
                 up data on a regular interval. For more
                 information, read Creating persistent
-                disk snapshots.
+                disk snapshots. LINT.IfChange
 
         """
         # Create or coerce a protobuf request object.
@@ -2227,5 +2228,7 @@ DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=package_version.__version__
 )
 
+if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
+    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__
 
 __all__ = ("SnapshotsClient",)
